<?php

namespace IMATHUZH\Qfq\Core\Renderer\Element\Bootstrap3;

use IMATHUZH\Qfq\Core\Helper\Support;
use IMATHUZH\Qfq\Core\Renderer\Element\ButtonRenderer;

class Bootstrap3ButtonRenderer extends ButtonRenderer {

    /**
     * Generic function to create a button based on a spec array
     *
     * @param array $elementSpec ['url'] -> link opened onclick of the button
     *                              ['buttonHtmlId'] -> HTML id of the button element
     *                              ['text'] -> HTML id of the button element
     *                              ['tooltip'] -> HTML id of the button element
     *                              ['icon'] -> name of the icon, e.g. "glyphicon-pencil"
     *                              ['disabled'] -> button disabled if this is set (no specific value needed)
     *                              ['class'] -> css class of the button
     *                              ['onChangeClass'] -> css class that is assigned to the button when form input changes
     *
     * @param array $elementSpec
     * @param string $renderMode
     * @return string
     */
    public function render(array $elementSpec, string $renderMode = RENDER_MODE_HTML): string {
        return self::renderStatic($elementSpec, $renderMode);
    }

    /**
     * Renders a button
     *
     * @param array $elementSpec
     * @param string $renderMode
     * @return string
     * @throws \CodeException
     */
    public static function renderStatic(array $elementSpec, string $renderMode = RENDER_MODE_HTML): string {
        $innerHTML = "";
        if (!isset($elementSpec['text'])) $elementSpec['text'] = "";
        if (!isset($elementSpec['icon']) || $elementSpec['icon'] === "") {
            $innerHTML = $elementSpec['text'];
        } else {
            $innerHTML = "<span " . Support::doAttribute('class', "glyphicon " . $elementSpec['icon']) . "></span> " . $elementSpec['text'];
        }

        $attribute = "";
        if (isset($elementSpec['url'])) $attribute .= Support::doAttribute('href', $elementSpec['url']);
        if (isset($elementSpec['buttonHtmlId'])) $attribute .= Support::doAttribute('id', $elementSpec['buttonHtmlId']);
        if (isset($elementSpec['class'])) $attribute .= Support::doAttribute('class', $elementSpec['class']);
        if (isset($elementSpec['tooltip'])) $attribute .= Support::doAttribute('title', $elementSpec['tooltip']);
        if (isset($elementSpec['onChangeClass'])) $attribute .= Support::doAttribute('data-class-on-change', $elementSpec['onChangeClass']);
        if (isset($elementSpec['onClick'])) $attribute .= Support::doAttribute('onClick', $elementSpec['onClick']);
        if (isset($elementSpec['sip'])) $attribute .= Support::doAttribute('data-sip', $elementSpec['sip']);
        if (isset($elementSpec['baseUrl'])) $attribute .= Support::doAttribute('data-base-url', $elementSpec['baseUrl']);
        if (isset($elementSpec['tablesorterView'])) $attribute .= Support::doAttribute('data-tablesorter-view-json', $elementSpec['tablesorterView']);
        if (isset($elementSpec['historyTitle'])) $attribute .= Support::doAttribute('data-history-title', $elementSpec['historyTitle']);
        if (isset($elementSpec['disabled'])) $attribute .= " disabled ";

        // disabled links do not show tooltips -> use a span
        $wrapTag = 'button';
        if (isset($elementSpec['disabled']) && $elementSpec['disabled'] != '') $wrapTag = 'span';
        if (isset($elementSpec['url'])) $wrapTag = 'a';
        if ($wrapTag == 'button') $attribute .= Support::doAttribute('type', 'button');

        return Support::wrapTag("<$wrapTag $attribute>", $innerHTML);
    }

}